<?php
include "DbConnection.php";
include "Bike.php";

/**
 * Die Klasse verarbeitet die Datenbankabfragen.
 */
class DbHandler {

    /**
     * Erstellt ein Array aus allen Fahrädern aus der Datenbankabfrage.
     * @param $result mysqli_result
     * @return array der Fahräder
     */
    private function resultToArray(mysqli_result $result): array {
        $items = array();
        if ($result->num_rows > 0) {
            while ($row = $result->fetch_assoc()) {
                $item = new Bike($row["TYP"], $row["BEZ"], $row["PREIS"], $row["GEWICHT"],
                    $row["RADGROESSE"], $row["GAENGE"], $row["ELEKTRO"], $row["BREMSE"],
                    $row["BELEUCHTUNG"], $row["BILD"], $row["RAHMENHOEHE"], $this->getColor($row["PINDEX"]));
                $items[] = $item;
            }
        }
        return $items;
    }

    /**
     * Gibt die Farbe des Fahrrads zurück.
     * @param $pIndex int
     * @return string die Farbe
     */
    private function getColor(int $pIndex): string {
        $result = $this->executeQuery("SELECT FARBE FROM farbe WHERE FINDEX = " . $pIndex . ";");
        if ($result->num_rows > 0) {
            $res = "";
            while ($row = $result->fetch_assoc()) {
                $res .= $row["FARBE"] . " ";
            }
            return $res;
        }
        return "n.A.";
    }
    /**
     * Führt die Query aus und gibt das Ergebnis zurück.
     * @param $query string
     * @return mysqli_result|bool das Ergebnis
     */
    public function executeQuery(string $query): mysqli_result|bool {
        $conn = connectToDb();
        $result = $conn->query($query);
        if (!$result) {
            die("Query failed: " . $conn->error . "<br>Query: " . $query);
        }
        $conn->close();
        return $result;
    }

    /**
     * Fügt die Filter der Query hinzu.
     * @return array Die gefilterten Fahräder
     */
    public function getFilteredItems($filters): array {
        $query = "SELECT * FROM fahrrad";
        if (count($filters) > 0) {
            $query .= " WHERE ";
            foreach ($filters as $filter) {
                $query .= $filter;
                if ($filter !== end($filters)) {
                    $query .= " AND ";
                }
            }
        }
        $query .= ";";
        $result = $this->executeQuery($query);
        return $this->resultToArray($result);
    }

    /**
     * Fügt die Sortierung der Query hinzu.
     * @return array Die sortierten Fahräder
     */
    public function getSortedItems(array $filters, string $sort): array {
        $query = "SELECT * FROM fahrrad";
        if (count($filters) > 0) {
            $query .= " WHERE ";
            foreach ($filters as $filter) {
                $query .= $filter;
                if ($filter !== end($filters)) {
                    $query .= " AND ";
                }
            }
            $query .= " ORDER BY " . $sort;
        }
        $query .= ";";
        $result = $this->executeQuery($query);

        return $this->resultToArray($result);
    }
}
